@@ -130,6 +130,9 @@ aaline(PyObject *self, PyObject *arg, PyObject *kwargs)
 
     surf = pgSurface_AsSurface(surfobj);
 
+    if (!surf)
+        return RAISE(pgExc_SDLError, "display Surface quit");
+
     if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4) {
         return PyErr_Format(PyExc_ValueError,
                             "unsupported surface bit depth (%d) for drawing",
@@ -192,6 +195,9 @@ line(PyObject *self, PyObject *arg, PyObject *kwargs)
 
     surf = pgSurface_AsSurface(surfobj);
 
+    if (!surf)
+        return RAISE(pgExc_SDLError, "display Surface quit");
+
     if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4) {
         return PyErr_Format(PyExc_ValueError,
                             "unsupported surface bit depth (%d) for drawing",
@@ -266,6 +272,9 @@ aalines(PyObject *self, PyObject *arg, PyObject *kwargs)
 
     surf = pgSurface_AsSurface(surfobj);
 
+    if (!surf)
+        return RAISE(pgExc_SDLError, "display Surface quit");
+
     if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4) {
         return PyErr_Format(PyExc_ValueError,
                             "unsupported surface bit depth (%d) for drawing",
@@ -399,6 +408,9 @@ lines(PyObject *self, PyObject *arg, PyObject *kwargs)
 
     surf = pgSurface_AsSurface(surfobj);
 
+    if (!surf)
+        return RAISE(pgExc_SDLError, "display Surface quit");
+
     if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4) {
         return PyErr_Format(PyExc_ValueError,
                             "unsupported surface bit depth (%d) for drawing",
@@ -521,6 +533,9 @@ arc(PyObject *self, PyObject *arg, PyObject *kwargs)
 
     surf = pgSurface_AsSurface(surfobj);
 
+    if (!surf)
+        return RAISE(pgExc_SDLError, "display Surface quit");
+
     if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4) {
         return PyErr_Format(PyExc_ValueError,
                             "unsupported surface bit depth (%d) for drawing",
@@ -596,6 +611,9 @@ ellipse(PyObject *self, PyObject *arg, PyObject *kwargs)
 
     surf = pgSurface_AsSurface(surfobj);
 
+    if (!surf)
+        return RAISE(pgExc_SDLError, "display Surface quit");
+
     if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4) {
         return PyErr_Format(PyExc_ValueError,
                             "unsupported surface bit depth (%d) for drawing",
@@ -679,6 +697,9 @@ circle(PyObject *self, PyObject *args, PyObject *kwargs)
 
     surf = pgSurface_AsSurface(surfobj);
 
+    if (!surf)
+        return RAISE(pgExc_SDLError, "display Surface quit");
+
     if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4) {
         return PyErr_Format(PyExc_ValueError,
                             "unsupported surface bit depth (%d) for drawing",
@@ -768,6 +789,9 @@ polygon(PyObject *self, PyObject *arg, PyObject *kwargs)
 
     surf = pgSurface_AsSurface(surfobj);
 
+    if (!surf)
+        return RAISE(pgExc_SDLError, "display Surface quit");
+
     if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4) {
         return PyErr_Format(PyExc_ValueError,
                             "unsupported surface bit depth (%d) for drawing",
@@ -884,6 +908,8 @@ rect(PyObject *self, PyObject *args, PyObject *kwargs)
     }
 
     surf = pgSurface_AsSurface(surfobj);
+    if (!surf)
+        return RAISE(pgExc_SDLError, "display Surface quit");
     if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4) {
         return PyErr_Format(PyExc_ValueError,
                             "unsupported surface bit depth (%d) for drawing",
@@ -1999,6 +2025,15 @@ draw_circle_filled(SDL_Surface *surf, int x0, int y0, int radius, Uint32 color,
     int ddF_y = -2 * radius;
     int x = 0;
     int y = radius;
+    int xmin = INT_MAX;
+    int xmax = INT_MIN;
+
+    if (x0 < 0) {
+        xmin = x0 + INT_MAX + 1;
+    }
+    else {
+        xmax = INT_MAX - x0;
+    }
 
     while (x < y) {
         if (f >= 0) {
@@ -2013,15 +2048,16 @@ draw_circle_filled(SDL_Surface *surf, int x0, int y0, int radius, Uint32 color,
         /* optimisation to avoid overdrawing and repeated return rect checks:
            only draw a line if y-step is about to be decreased. */
         if (f >= 0) {
-            drawhorzlineclipbounding(surf, color, x0 - x, y0 + y - 1,
-                                     x0 + x - 1, drawn_area);
-            drawhorzlineclipbounding(surf, color, x0 - x, y0 - y, x0 + x - 1,
+            drawhorzlineclipbounding(surf, color, x0 - MIN(x, xmin),
+                                     y0 + y - 1, x0 + MIN(x - 1, xmax),
                                      drawn_area);
+            drawhorzlineclipbounding(surf, color, x0 - MIN(x, xmin), y0 - y,
+                                     x0 + MIN(x - 1, xmax), drawn_area);
         }
-        drawhorzlineclipbounding(surf, color, x0 - y, y0 + x - 1, x0 + y - 1,
-                                 drawn_area);
-        drawhorzlineclipbounding(surf, color, x0 - y, y0 - x, x0 + y - 1,
-                                 drawn_area);
+        drawhorzlineclipbounding(surf, color, x0 - MIN(y, xmin), y0 + x - 1,
+                                 x0 + MIN(y - 1, xmax), drawn_area);
+        drawhorzlineclipbounding(surf, color, x0 - MIN(y, xmin), y0 - x,
+                                 x0 + MIN(y - 1, xmax), drawn_area);
     }
 }
 
